@@ -44,7 +44,7 @@ var tutorialInstructions = [
                 "instructionQml": "qrc:/gcompris/src/activities/binary_bulb/resource/tutorial4.qml"
             },
             {
-                "instruction": qsTr("Each bit had a progressive value, corresponding to the powers of 2, ascending from right to left: bit 1 → 2⁰=1 , bit 2 → 2¹=2 , bit 3 → 2²=4 , bit 4 → 2³=8 , bit 5 → 2⁴=16 , bit 6 → 2⁵=32 , bit 7 → 2⁶=64 , bit 8 → 2⁷=128."),
+                "instruction": qsTr("Each bit adds a progressive value, corresponding to the powers of 2, ascending from right to left: bit 1 → 2⁰=1 , bit 2 → 2¹=2 , bit 3 → 2²=4 , bit 4 → 2³=8 , bit 5 → 2⁴=16 , bit 6 → 2⁵=32 , bit 7 → 2⁶=64 , bit 8 → 2⁷=128."),
                 "instructionQml": "qrc:/gcompris/src/activities/binary_bulb/resource/tutorial5.qml"
             },
             {
