@@ -113,7 +113,9 @@ int main(int argc, char *argv[])
     app.setApplicationName(GCOMPRIS_APPLICATION_NAME);
     app.setOrganizationDomain("kde.org");
     app.setApplicationVersion(ApplicationInfo::GCVersion());
-
+    
+    //add a variable to disable default fullscreen on Mac, see below..
+    bool isOnMac = false;
 #if defined(Q_OS_MAC)
     // Sandboxing on MacOSX as documented in:
     // http://doc.qt.io/qt-5/osx-deployment.html
@@ -121,6 +123,7 @@ int main(int argc, char *argv[])
     dir.cdUp();
     dir.cd("Plugins");
     QGuiApplication::setLibraryPaths(QStringList(dir.absolutePath()));
+    isOnMac = true;
 #endif
 
     // Local scope for config
@@ -191,6 +194,10 @@ int main(int argc, char *argv[])
         if(config.contains("General/fullscreen")) {
             isFullscreen = config.value("General/fullscreen").toBool();
         }
+        //Disable default fullscreen launch on Mac as it's a bit broken, window is behind desktop bars
+        if(isOnMac) {
+            isFullscreen = false;
+        }
 
         // Set the cursor image
         bool defaultCursor = false;
@@ -264,6 +271,8 @@ int main(int argc, char *argv[])
                          .arg(QCoreApplication::applicationDirPath()));
 #endif
 
+    ApplicationInfo::getInstance()->setBox2DInstalled(engine);
+
     if(parser.isSet(exportActivitiesAsSQL)) {
         ActivityInfoTree *menuTree(qobject_cast<ActivityInfoTree*>(ActivityInfoTree::menuTreeProvider(&engine, nullptr)));
         menuTree->exportAsSQL();
@@ -277,7 +286,6 @@ int main(int argc, char *argv[])
         qWarning("Error: Your root item has to be a Window.");
         return -1;
     }
-
     ApplicationInfo::setWindow(window);
 
     window->setIcon(QIcon(QPixmap(QString::fromUtf8(":/gcompris/src/core/resource/gcompris-icon.png"))));
